@@ -1,9 +1,8 @@
 """A window that displays the last donation. Useful during streaming."""
 
-import sys
-from PyQt5.QtWidgets import QDialog, QApplication, QGraphicsScene, QGraphicsPixmapItem
-from PyQt5.QtCore import QUrl, Qt
-from PyQt5.QtMultimedia import QMediaPlayer, QMediaContent
+from PyQt5.QtWidgets import QDialog, QGraphicsScene, QGraphicsPixmapItem
+from PyQt5.QtCore import QUrl
+from PyQt5.QtMultimedia import QMediaPlayer, QMediaContent  # type: ignore
 from PyQt5.QtGui import QFont, QColor
 
 from eldonationtracker.tracker import *
@@ -13,7 +12,7 @@ from eldonationtracker import ipc as ipc
 class MyForm(QDialog):
     """The class to hold the tracker window."""
 
-    def __init__(self, participant_conf):
+    def __init__(self, participant_conf, participant):
         """Set up the window.
 
         Loads in the image and sound file the user specified in the
@@ -24,6 +23,7 @@ class MyForm(QDialog):
         self.ui.setupUi(self)
         # config stuff
         self.participant_conf = participant_conf
+        self.participant = participant
         self.folders = self.participant_conf.get_text_folder_only()
         (self.font_family, self.font_size, self.font_italic, self.font_bold,
          self.font_color_value) = self.participant_conf.get_font_info()
@@ -48,28 +48,28 @@ class MyForm(QDialog):
             self.ui.graphicsView.setBackgroundBrush(self.tracker_background_color)
         self.scene = QGraphicsScene(self)
         self.pixmap = QtGui.QPixmap()
-        self._loadimage()
+        self._load_image()
         self.ui.graphicsView.setScene(self.scene)
         self.donation_player = QMediaPlayer()
-        self._loadsound()
+        self._load_sound()
         # timer to update the main text
         self.timer = QtCore.QTimer(self)
         self.timer.setSingleShot(False)
         self.timer.setInterval(20000)  # milliseconds
-        self.timer.timeout.connect(self._loadAndUnload)
+        self.timer.timeout.connect(self._load_and_unload)
         self.timer.start()
 
-    def _loadimage(self):
+    def _load_image(self):
         self.tracker_image = self.participant_conf.get_tracker_image()
         self.pixmap.load(self.tracker_image)
         self.item = QGraphicsPixmapItem(self.pixmap.scaledToHeight(131))
 
-    def _loadsound(self):
+    def _load_sound(self):
         sound_to_play = self.participant_conf.get_tracker_sound()
-        self.donation_sound= QMediaContent(QUrl.fromLocalFile(sound_to_play))
+        self.donation_sound = QMediaContent(QUrl.fromLocalFile(sound_to_play))
         self.donation_player.setMedia(self.donation_sound)
 
-    def loadAndUnloadTest(self):
+    def load_and_unload_test(self):
         """Trigger the tracker functionality.
 
         This causes the image and sound to load so that the
@@ -77,52 +77,42 @@ class MyForm(QDialog):
         or XSplit screen as well as to make sure they can hear
         the sound. Called by gui.py.
         """
-        self._loadimage()
-        self._loadElements()
-        self._loadsound()
+        self._load_image()
+        self._load_elements()
+        self._load_sound()
         self.donation_player.play()
-        unloadtimer = QtCore.QTimer(self)
-        unloadtimer.setSingleShot(True)
-        unloadtimer.setInterval(5000)  # milliseconds
-        unloadtimer.timeout.connect(self._unloadElements)
-        unloadtimer.start()
+        unload_timer = QtCore.QTimer(self)
+        unload_timer.setSingleShot(True)
+        unload_timer.setInterval(5000)  # milliseconds
+        unload_timer.timeout.connect(self._unload_elements)
+        unload_timer.start()
 
-    def _loadAndUnload(self):
+    def _load_and_unload(self):
         self.folders = self.participant_conf.get_text_folder_only()
-        IPC = "0"
-        try:
-            with open(f'{self.folders}/trackerIPC.txt') as file:
-                IPC = file.read(1)
-                file.close()
-        except:
-            print("""tackerIPC.txt not found.
-                Have you updated the settings?
-                Have you hit the 'run' button?""")
-        if IPC == "1":
-            self._loadimage()
-            self._loadElements()
-            self._loadsound()
+        if self.participant.new_donation:
+            self._load_image()
+            self._load_elements()
+            self._load_sound()
             self.donation_player.play()
-            unloadtimer = QtCore.QTimer(self)
-            unloadtimer.setSingleShot(True)
-            unloadtimer.setInterval(5000)  # milliseconds
-            unloadtimer.timeout.connect(self._unloadElements)
-            unloadtimer.start()
+            unload_timer = QtCore.QTimer(self)
+            unload_timer.setSingleShot(True)
+            unload_timer.setInterval(5000)  # milliseconds
+            unload_timer.timeout.connect(self._unload_elements)
+            unload_timer.start()
 
-    def _loadElements(self):
+    def _load_elements(self):
         self.scene.addItem(self.item)
         try:
             with open(f'{self.folders}/LastDonationNameAmnt.txt') as file:
-                donorAndAmt = file.read()
-                file.close
-            self.ui.Donation_label.setText(donorAndAmt)
+                donor_and_amt = file.read()
+            self.ui.Donation_label.setText(donor_and_amt)
         except FileNotFoundError:
             self.ui.Donation_label.setText("TEST 1...2...3...")
 
-    def _unloadElements(self):
+    def _unload_elements(self):
         self.scene.removeItem(self.item)
         self.ui.Donation_label.setText("")
-        ipc.writeIPC(self.folders, "0")
+        self.participant.new_donation = False
 
     def set_font(self, font):
         self.ui.Donation_label.setFont(font)
@@ -138,9 +128,3 @@ def main(participant_conf):
     """Launch the window."""
     window = MyForm(participant_conf)
     window.exec()
-
-if __name__ == "__main__":
-    app = QApplication(sys.argv)
-    w = MyForm()
-    w.show()
-    sys.exit(app.exec_())
